import {baseResource} from './baseResource';

/**
 * CustomFieldOption 
 *
 * @constructor CustomFieldOption
 * @property {IConnector} connector the jira connector instance
 */

export class CustomFieldOption extends baseResource {

    constructor (connector:IConnector,Model:any,settings:any) {
        super(connector,Model,settings);
        this.methods = [];
        this.register();
    }

    
    /**
     * Returns a full representation of the Custom Field Option that has the given id.
     *
     * @method findById
     * @memberOf CustomFieldOption#
     * @param {Object} options An object containing options to pass to the Jira API.
     * @param {string} options.id id 
     * @param {string} options.token token The token to use for authentication. This token is supplied on a sucessful login. If not supplied, the default token (if set) is used
     * @param [callback] if supplied, called with result of api call
     * @return {Promise.<any>} result of api call
     */

    findById = (...args : any[]):Promise<any> => {
        let callback = ((typeof args[args.length - 1]) === 'function') ? args.pop() : null;

        let options = ((typeof args[0]) === 'object') ? args[0] : {
             "id": args[0],
             "token": args[1]
            
        };

        return this.makeRequest('findById','GET','rest/api/2/customFieldOption/:id',options,callback)
    };
    

}
